#include "segway_RMP400_exception.h"
#include <string>
#include <sstream>

const std::string segway_rmp400_exception_msg = "[CSegwayRMP400 class] - ";

CSegwayRMP400Exception::CSegwayRMP400Exception(const std::string & where,
                                               const std::string & error_msg,
                                               const std::string & segway_id) throw () :
    CException(where, segway_rmp400_exception_msg + error_msg + "-" + segway_id)
{
}

CSegwayRMP400Exception::CSegwayRMP400Exception(const std::string & where,
                                               const std::string & error_msg) throw () :
    CException(where, segway_rmp400_exception_msg)
{
}

RMP400IdemSerialException::RMP400IdemSerialException(const std::string & where,
                                                     const std::string & serial) throw () :
    CSegwayRMP400Exception(where, segway_rmp400_exception_msg)
{
    error_msg += "Serial ports are the same for two segways: " + serial;
}

RMP400NotFoundSerialException::RMP400NotFoundSerialException(const std::string & where,
                                                             const std::string & serial) throw () :

    CSegwayRMP400Exception(where, segway_rmp400_exception_msg)
{
    error_msg += "Serial port found: " + serial + " not inside valid ports supplied";
}


RMP400NotValidNumberRMP200Exception::RMP400NotValidNumberRMP200Exception(const std::string & where,
                                                                         const int & number_found) throw () :
    CSegwayRMP400Exception(where, segway_rmp400_exception_msg)
{
    std::stringstream s;
    s << number_found;

    error_msg += "Found " + s.str() + " RMP200 units which is not valid for this device";
}

RMP400InvalidBalanceModeOperation::RMP400InvalidBalanceModeOperation(const std::string & where) throw () :
    CSegwayRMP400Exception(where, segway_rmp400_exception_msg)
{
    error_msg += "Balance mode for the segway RMP400 is completly crazy";
}

RMP400NoConnected::RMP400NoConnected(const std::string & where) throw () :
    CSegwayRMP400Exception(where, segway_rmp400_exception_msg)
{
    error_msg += "Segway RMP 400 has not been connected";
}
