/* vim: set sw=4 sts=4 et foldmethod=syntax : */

#include <gtest/gtest.h>
#include "segway_RMP400.h" 
#include "exceptions.h"

int g_argc;
char** g_argv;

TEST(Driver, basic_move)
{
    CSegwayRMP400 * segway = new CSegwayRMP400();
    segway->start();
    ASSERT_NO_THROW(segway->move(0.3,0.3));
    sleep(3);
    segway->move(0.0,0.0);
    segway->stop();
    delete segway;
}

TEST(Driver, reset_integrators_after_move)
{
    CSegwayRMP400 * segway = new CSegwayRMP400();
    segway->start();
    segway->reset_integrators();
    segway->move(0.2,0.0);
    sleep(2);
    segway->move(0.0,0.2);
    sleep(2);
    segway->move(0.0,0.0);
    sleep(2);
    segway->reset_integrators();
    ASSERT_NEAR(segway->get_forward_displacement(), 0.0, 0.1);
    ASSERT_NEAR(segway->get_yaw_displacement(), 0.0, 0.1);
    segway->stop();
    delete segway;
}

TEST(Driver, get_forward_displacement)
{
    CSegwayRMP400 * segway = new CSegwayRMP400();
    segway->start();
    segway->reset_integrators();
    segway->move(0.2,0.0);
    sleep(3);
    ASSERT_GT(segway->get_forward_displacement(), 0.0);
    segway->stop();
    delete segway;
}

TEST(Driver, get_forward_negative_displacement)
{
    CSegwayRMP400 * segway = new CSegwayRMP400();
    segway->start();
    segway->reset_integrators();
    segway->move(-0.2,0.0);
    sleep(3);
    ASSERT_LT(segway->get_forward_displacement(), 0.0);
    segway->stop();
    delete segway;
}

TEST(Driver, get_yaw_displacement)
{
    CSegwayRMP400 * segway = new CSegwayRMP400();
    segway->start();
    segway->reset_integrators();
    segway->move(0.0,0.2);
    sleep(3);
    ASSERT_GT(segway->get_yaw_displacement(), 0.0);
    segway->stop();
    delete segway;
}

TEST(Driver, get_yaw_negative_displacement)
{
    CSegwayRMP400 * segway = new CSegwayRMP400();
    segway->start();
    segway->reset_integrators();
    segway->move(0.0,-0.2);
    sleep(3);
    ASSERT_LT(segway->get_yaw_displacement(), 0.0);
    segway->stop();
    delete segway;
}

TEST(Driver, get_yaw_rate)
{
    CSegwayRMP400 * segway = new CSegwayRMP400();
    segway->start();
    segway->move(0.0,0.3);
    sleep(3);
    ASSERT_GT(segway->get_yaw_rate(), 0.0);
    segway->stop();
    delete segway;
}

int main(int argc, char **argv)
{
     testing::InitGoogleTest(&argc, argv);
     g_argc = argc;
     g_argv = argv;
     return RUN_ALL_TESTS();
}
